package com.javacodegeeks.dw.web;

import java.util.Collection;
import java.util.Optional;
import java.util.stream.Collectors;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;

import com.javacodegeeks.dw.persistence.Task;
import com.javacodegeeks.dw.persistence.TaskRepository;

import io.dropwizard.hibernate.UnitOfWork;

@Path("/tasks")
@Produces(MediaType.APPLICATION_JSON)
@Consumes(MediaType.APPLICATION_JSON)
public class TaskResource {
    private final TaskRepository repository;
    
    public TaskResource(TaskRepository repository) {
        this.repository = repository;
    }
    
    @POST
    @UnitOfWork
    public Collection<Task> create(Collection<Task> tasks) {
        return tasks.stream().map(repository::create).collect(Collectors.toList());
    }

    @GET
    @UnitOfWork
    public Collection<Task> list() {
        return repository.findAll();
    }

    @GET
    @Path("{id}")
    @UnitOfWork
    public Optional<Task> findById(@PathParam("id") int id) {
        return repository.findById(id);
    }
    
    @DELETE
    @Path("{id}")
    @UnitOfWork
    public void deleteById(@PathParam("id") int id) {
        repository.deleteById(id);
    }
}
